summaryrefslogtreecommitdiffstats
path: root/lib/kformula/textelement.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/textelement.h')
-rw-r--r--lib/kformula/textelement.h72
1 files changed, 36 insertions, 36 deletions
diff --git a/lib/kformula/textelement.h b/lib/kformula/textelement.h
index bac10acc..0b97f441 100644
--- a/lib/kformula/textelement.h
+++ b/lib/kformula/textelement.h
@@ -21,8 +21,8 @@
#ifndef TEXTELEMENT_H
#define TEXTELEMENT_H
-#include <qfont.h>
-#include <qstring.h>
+#include <tqfont.h>
+#include <tqstring.h>
#include "basicelement.h"
@@ -38,7 +38,7 @@ class TextElement : public BasicElement {
TextElement operator=( const TextElement& ) { return *this; }
public:
- TextElement(QChar ch = ' ', bool beSymbol = false, BasicElement* parent = 0);
+ TextElement(TQChar ch = ' ', bool beSymbol = false, BasicElement* tqparent = 0);
TextElement( const TextElement& );
virtual TextElement* clone() {
@@ -62,7 +62,7 @@ public:
* @returns the character that represents this element. Used for
* parsing a sequence.
*/
- virtual QChar getCharacter() const { return character; }
+ virtual TQChar getCharacter() const { return character; }
// drawing
//
@@ -73,7 +73,7 @@ public:
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -81,26 +81,26 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
/**
- * Dispatch this FontCommand to all our TextElement children.
+ * Dispatch this FontCommand to all our TextElement tqchildren.
*/
virtual void dispatchFontCommand( FontCommand* cmd );
/**
* Set the color to use to display
*/
- void setColor( QColor c ) { color = c; }
+ void setColor( TQColor c ) { color = c; }
CharStyle getCharStyle() const { return charStyle(); }
void setCharStyle( CharStyle cs );
@@ -123,13 +123,13 @@ public:
/**
* @returns the latex representation of the element and
- * of the element's children
+ * of the element's tqchildren
*/
- virtual QString toLatex();
+ virtual TQString toLatex();
- virtual QString formulaString();
+ virtual TQString formulaString();
- virtual void writeMathML( QDomDocument& doc, QDomNode& parent, bool oasisFormat = false ) const ;
+ virtual void writeMathML( TQDomDocument& doc, TQDomNode& tqparent, bool oasisFormat = false ) const ;
protected:
@@ -138,40 +138,40 @@ protected:
/**
* @returns the tag name of this element type.
*/
- virtual QString getTagName() const { return "TEXT"; }
+ virtual TQString getTagName() const { return "TEXT"; }
/**
* Appends our attributes to the dom element.
*/
- virtual void writeDom(QDomElement element);
+ virtual void writeDom(TQDomElement element);
/**
* Reads our attributes from the element.
* Returns false if it failed.
*/
- virtual bool readAttributesFromDom(QDomElement element);
+ virtual bool readAttributesFromDom(TQDomElement element);
/**
* Reads our content from the node. Sets the node to the next node
* that needs to be read.
* Returns false if it failed.
*/
- virtual bool readContentFromDom(QDomNode& node);
+ virtual bool readContentFromDom(TQDomNode& node);
/**
* @returns the char that is used to draw with the given font.
*/
- QChar getRealCharacter(const ContextStyle& context);
+ TQChar getRealCharacter(const ContextStyle& context);
/**
* @returns the font to be used for the element.
*/
- QFont getFont(const ContextStyle& context, const StyleAttributes& style);
+ TQFont getFont(const ContextStyle& context, const StyleAttributes& style);
/**
* Sets up the painter to be used for drawing.
*/
- void setUpPainter(const ContextStyle& context, QPainter& painter);
+ void setUpPainter(const ContextStyle& context, TQPainter& painter);
const SymbolTable& getSymbolTable() const;
@@ -180,7 +180,7 @@ private:
/**
* Our content.
*/
- QChar character;
+ TQChar character;
/**
* Whether this character is a symbol.
@@ -190,7 +190,7 @@ private:
/**
* Color to display. Set by container.
*/
- QColor color;
+ TQColor color;
/**
* The attribute of the char. "anyChar" means leave the default.
@@ -226,7 +226,7 @@ class EmptyElement : public BasicElement {
EmptyElement& operator=( const EmptyElement& ) { return *this; }
public:
- EmptyElement( BasicElement* parent = 0 );
+ EmptyElement( BasicElement* tqparent = 0 );
EmptyElement( const EmptyElement& );
virtual EmptyElement* clone() {
@@ -240,11 +240,11 @@ public:
* parsing a sequence.
* Here we use a dummy so an EmptyElement pretends to be a letter.
*/
- virtual QChar getCharacter() const { return 'A'; }
+ virtual TQChar getCharacter() const { return 'A'; }
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -252,23 +252,23 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
/**
* @returns the latex representation of the element and
- * of the element's children
+ * of the element's tqchildren
*/
- virtual QString toLatex();
+ virtual TQString toLatex();
protected:
@@ -277,7 +277,7 @@ protected:
/**
* @returns the tag name of this element type.
*/
- virtual QString getTagName() const { return "EMPTY"; }
+ virtual TQString getTagName() const { return "EMPTY"; }
};
@@ -81,26 +81,26 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/
@@ -252,23 +252,23 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/